@@ -1,13 +1,11 @@
-"""
-Functions to aid in preserving the test database between test runs.
+"""Functions to aid in preserving the test database between test runs.
 
 The code in this module is heavily inspired by django-nose:
 https://github.com/jbalogh/django-nose/
 """
 
 import new
-
-from django.db import connections
+import py
 
 
 def can_support_db_reuse(connection):
@@ -42,7 +40,6 @@ def create_test_db(self, verbosity=1, autoclobber=False):
     will not actually create a new database, but just reuse the
     existing.
     """
-
     test_database_name = self._get_test_db_name()
     self.connection.settings_dict['NAME'] = test_database_name
 
@@ -59,6 +56,8 @@ def create_test_db(self, verbosity=1, autoclobber=False):
 
 
 def monkey_patch_creation_for_db_reuse():
+    from django.db import connections
+
     for alias in connections:
         connection = connections[alias]
         creation = connection.creation
